@@ -62,7 +62,7 @@ def make_primary(domain, force, skip_replace):
 		click.echo('- Running search-replace')
 
 		for sproto in ['https://', 'http://']:
-			c.run(wp + shlex.join([
+			c.run(wp + util.join([
 				'search-replace',
 				sproto + current,
 				proto + domain['name'],
@@ -143,7 +143,7 @@ def make_https(domains, agree_tos):
 			args.append(name)
 
 		try:
-			c.run(shlex.join(args))
+			c.run(util.join(args))
 		except Exception as e:
 			util.dlog(e)
 			raise click.ClickException('Could not obtain SSL certificate for %s. Use --debug for more info.' % group)
@@ -270,8 +270,9 @@ def add(domains, skip_dns):
 
 @domain.command()
 @click.option('--skip-dns', is_flag=True, help='Do not delete DNS records')
+@click.option('--zone', is_flag=True, help='Force delete a DNS zone, even if other records exist in the zone.')
 @click.argument('domains', nargs=-1)
-def delete(domains, skip_dns):
+def delete(domains, skip_dns, zone):
 	'''Delete a domain and all DNS records'''
 	config = util.config()
 
@@ -299,6 +300,20 @@ def delete(domains, skip_dns):
 		click.echo('- Skipping updating DNS records')
 		return
 
+	# Delete orphans if the entire zone is going to be deleted.
+	if zone:
+		for domain in domains:
+			_, _subs = _parse_domains([d['name'] for d in config['domains'] if d['internal'] != True])
+			for _sub in _subs:
+				if _sub.registered_domain == domain.fqdn:
+					click.echo('- Deleting orphaned subdomain %s from .sail/config.json' % _sub.fqdn)
+					config['domains'] = [d for d in config['domains'] if d['name'] != _sub.fqdn]
+					util.update_config(config)
+
+	_delete_dns_records(domains, subdomains, force_delete_zones=zone)
+
+def _delete_dns_records(domains, subdomains, force_delete_zones=False):
+	config = util.config()
 	manager = digitalocean.Manager(token=config['provider_token'])
 	existing = manager.get_all_domains()
 
@@ -332,18 +347,42 @@ def delete(domains, skip_dns):
 
 		try:
 			do_domain = digitalocean.Domain(token=config['provider_token'], name=domain.fqdn)
-			do_domain.destroy()
-			click.echo('- Deleting DNS zone for %s' % domain.fqdn)
+			records = do_domain.get_records()
+			exists = False
+			delete_zone = True
+
+			if force_delete_zones:
+				click.echo('- Deleting DNS zone for %s, forced' % domain.fqdn)
+				do_domain.destroy()
+				continue
+
+			for r in records:
+				if r.name == '@' and r.type == 'A' and r.data == config['ip']:
+					exists = True
+					click.echo('- Deleting A record for %s' % domain.fqdn)
+					r.destroy()
+					continue
+
+				if r.name == '@' and r.type == 'NS':
+					continue
+
+				if r.name == '@' and r.type == 'SOA':
+					continue
+
+				# There are more records, don't delete the zone
+				delete_zone = False
+
+			if not exists:
+				click.echo('- No A records to delete for %s' % domain.fqdn)
+
+			if delete_zone:
+				do_domain.destroy()
+				click.echo('- Deleting DNS zone for %s' % domain.fqdn)
+			else:
+				click.echo('- Skipping deleting DNS zone for %s, other records exist' % domain.fqdn)
 		except:
 			click.echo('- Could not delete DNS zone for %s' % domain.fqdn)
 
-		_, _subs = _parse_domains([d['name'] for d in config['domains'] if d['internal'] != True])
-		for _sub in _subs:
-			if _sub.registered_domain == domain.fqdn:
-				click.echo('- Deleting orphaned subdomain %s from .sail/config.json' % _sub.fqdn)
-				config['domains'] = [d for d in config['domains'] if d['name'] != _sub.fqdn]
-				util.update_config(config)
-
 def _update_nginx_config():
 	config = util.config()
 	domains = config['domains']
